@@ -18,6 +18,22 @@
 #define CLOCK_GCONF_PATH "/apps/clock"
 #define CLOCK_GCONF_IS_24H_FORMAT CLOCK_GCONF_PATH  "/time-format"
 
+#define COUNTDOWN_HOME_WIDGET_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE (obj,\
+							                         COUNTDOWN_TYPE_HOME_WIDGET,\
+							                         CountdownHomeWidgetPrivate))
+
+struct _CountdownHomeWidgetPrivate
+{
+    GtkWidget *homeWidget;
+    GtkWidget *contents;
+	GtkWidget *buttons;
+	GtkWidget *upButton, *downButton;
+    GtkListStore *entries;
+    guint refresh;
+	guint offset;
+    guint eventID;
+};
+
 HD_DEFINE_PLUGIN_MODULE (CountdownHomeWidget, countdown_home_widget,
   HD_TYPE_HOME_PLUGIN_ITEM)
 
@@ -25,21 +41,21 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self);
 
 gboolean check_ampm_format ()
 {
-  //g_warning ("check_ampm_format");
-  GConfClient *client = NULL;
-  gboolean value = TRUE;
-  GError *error = NULL;
+	//g_warning ("check_ampm_format");
+	GConfClient *client = NULL;
+	gboolean value = TRUE;
+	GError *error = NULL;
 
-  client = gconf_client_get_default ();
-  value = gconf_client_get_bool (client, CLOCK_GCONF_IS_24H_FORMAT, &error);
-  if (error != NULL) {
-    g_warning
-      ("Error trying to get gconf variable %s, using 24h format by default",
-       CLOCK_GCONF_IS_24H_FORMAT);
-    g_error_free (error);
-  }
+	client = gconf_client_get_default ();
+	value = gconf_client_get_bool (client, CLOCK_GCONF_IS_24H_FORMAT, &error);
+	if (error != NULL) {
+		g_warning
+			("Error trying to get gconf variable %s, using 24h format by default",
+			CLOCK_GCONF_IS_24H_FORMAT);
+		g_error_free (error);
+	}
 
-  return !value;
+	return !value;
 }
 
 void countdown_home_widget_write_settings (CountdownHomeWidget *self)
@@ -55,25 +71,24 @@ void countdown_home_widget_write_settings (CountdownHomeWidget *self)
 	gint i=0;
 	
 	keyFile = g_key_file_new();
-	exists = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (self->entries), &iter);
-	while (exists)
-	{
+	exists = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (self->priv->entries), &iter);
+	while (exists) {
 		gchar *title, *date, *time;
 		gboolean showWhich[5];
 		gchar entry[5];
 		snprintf(entry, 5, "%d", i++);
-		gtk_tree_model_get(GTK_TREE_MODEL (self->entries),&iter,0,&title,1,&date,2,&time,4,&showWhich[0],5,&showWhich[1],6,&showWhich[2],7,&showWhich[3],8,&showWhich[4],-1);
+		gtk_tree_model_get(GTK_TREE_MODEL (self->priv->entries),&iter,0,&title,1,&date,2,&time,4,&showWhich[0],5,&showWhich[1],6,&showWhich[2],7,&showWhich[3],8,&showWhich[4],-1);
 		g_key_file_set_string(keyFile,entry,"title",title);
 		g_key_file_set_string(keyFile,entry,"date",date);
 		g_key_file_set_string(keyFile,entry,"time",time);
 		g_key_file_set_boolean_list(keyFile,entry,"show",showWhich,5);
-		exists=gtk_tree_model_iter_next(GTK_TREE_MODEL (self->entries),&iter);
+		exists=gtk_tree_model_iter_next(GTK_TREE_MODEL (self->priv->entries),&iter);
 		g_free(title);
 		g_free(date);
 		g_free(time);
 	}
 	
-	g_key_file_set_integer (keyFile, "config", "refresh", self->refresh);
+	g_key_file_set_integer (keyFile, "config", "refresh", self->priv->refresh);
 	
 	filename = g_strconcat (HOME_DIR, "/.countdown_home.ini", NULL);
 	fileData = g_key_file_to_data (keyFile, &size, NULL);
@@ -129,7 +144,7 @@ void countdown_home_widget_select_time (GtkButton *button, GtkWidget *dialog)
 	gtk_widget_hide (dialog);
 }
 
-void countdown_home_widget_add_event(GtkButton *button, CountdownHomeWidget *self)
+void countdown_home_widget_add_event(GtkWidget *button, GdkEventButton *event, CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_add_event");
 	GDate *date = g_date_new();
@@ -198,7 +213,7 @@ void countdown_home_widget_add_event(GtkButton *button, CountdownHomeWidget *sel
 	hildon_caption_set_separator (HILDON_CAPTION (timeCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), timeCaption);
 
-    GtkHBox *hbox = GTK_HBOX (gtk_hbox_new (0, FALSE));
+    GtkHBox *hbox = GTK_HBOX (gtk_hbox_new (FALSE, 0));
     toggleYears = gtk_toggle_button_new_with_label ("Year");
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleYears), TRUE);
     toggleWeeks = gtk_toggle_button_new_with_label ("Week");
@@ -222,8 +237,7 @@ void countdown_home_widget_add_event(GtkButton *button, CountdownHomeWidget *sel
     gtk_widget_show_all (dialog);
 
     int response=gtk_dialog_run (GTK_DIALOG (dialog));
-    if (response == GTK_RESPONSE_ACCEPT)
-    {
+    if (response == GTK_RESPONSE_ACCEPT) {
         const gchar *title = hildon_entry_get_text (HILDON_ENTRY (titleEntry));
         guint year, month, day;
         guint hours, minutes;
@@ -244,9 +258,9 @@ void countdown_home_widget_add_event(GtkButton *button, CountdownHomeWidget *sel
         tMinutes = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleMinutes));
         tHours = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleHours));
 
-		gtk_list_store_append (GTK_LIST_STORE (self->entries), &iter);
-		gtk_list_store_set (GTK_LIST_STORE (self->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
-		gtk_list_store_set (GTK_LIST_STORE (self->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
+		gtk_list_store_append (GTK_LIST_STORE (self->priv->entries), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
+		gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
 
         g_free (printDate);
         g_free (printTime);
@@ -258,10 +272,10 @@ void countdown_home_widget_add_event(GtkButton *button, CountdownHomeWidget *sel
     gtk_widget_destroy (dialog);
 }
 
-void countdown_home_widget_edit_event (GtkButton *button, CountdownHomeWidget *self)
+void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event, CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_edit_event");
-	gint index = g_ascii_strtoll (gtk_widget_get_name (GTK_WIDGET (button)), NULL, 10);
+	gint index = g_ascii_strtoll (gtk_widget_get_name (button), NULL, 10);
 	GtkWidget *dialog, *content_area;
     GtkWidget *titleEntry, *dateButton, *timeButton;
     GtkWidget *titleCaption, *dateCaption, *timeCaption;
@@ -306,7 +320,7 @@ void countdown_home_widget_edit_event (GtkButton *button, CountdownHomeWidget *s
 	hildon_caption_set_separator (HILDON_CAPTION (timeCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), timeCaption);
 
-    GtkHBox *hbox = GTK_HBOX (gtk_hbox_new (0, FALSE));
+    GtkHBox *hbox = GTK_HBOX (gtk_hbox_new (FALSE, 0));
     toggleYears = gtk_toggle_button_new_with_label ("Year");
     toggleWeeks = gtk_toggle_button_new_with_label ("Week");
     toggleDays = gtk_toggle_button_new_with_label ("Day");
@@ -322,8 +336,7 @@ void countdown_home_widget_edit_event (GtkButton *button, CountdownHomeWidget *s
     gtk_container_add (GTK_CONTAINER (content_area), displayCaption);
     
 	GtkTreeIter iter;
-	if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->entries), &iter, NULL, index))
-	{
+	if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, index)) {
 		gchar *titleText, *dateText, *timeText;
 		gboolean tYears, tWeeks, tDays;
 		gboolean tHours, tMinutes;
@@ -332,7 +345,7 @@ void countdown_home_widget_edit_event (GtkButton *button, CountdownHomeWidget *s
 		GDate date;
 		gint time;
 		
-		gtk_tree_model_get (GTK_TREE_MODEL (self->entries), &iter, 0, &titleText, 1, &dateText, 2, &timeText, 4, &tYears, 5, &tWeeks, 6, &tDays, 7, &tHours, 8, &tMinutes, -1);
+		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->entries), &iter, 0, &titleText, 1, &dateText, 2, &timeText, 4, &tYears, 5, &tWeeks, 6, &tDays, 7, &tHours, 8, &tMinutes, -1);
 		
 		g_date_set_parse (&date, dateText);
 		year = g_date_get_year (&date);
@@ -374,8 +387,7 @@ void countdown_home_widget_edit_event (GtkButton *button, CountdownHomeWidget *s
     gtk_widget_show_all (dialog);
 
     int response=gtk_dialog_run (GTK_DIALOG (dialog));
-    if (response == GTK_RESPONSE_ACCEPT)
-    {
+    if (response == GTK_RESPONSE_ACCEPT) {
         const gchar *title = hildon_entry_get_text (HILDON_ENTRY (titleEntry));
         guint year, month, day;
         guint hours, minutes;
@@ -396,10 +408,9 @@ void countdown_home_widget_edit_event (GtkButton *button, CountdownHomeWidget *s
         tMinutes = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleMinutes));
         tHours = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleHours));
 
-		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->entries), &iter, NULL, index))
-		{
-			gtk_list_store_set (GTK_LIST_STORE (self->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
-			gtk_list_store_set (GTK_LIST_STORE (self->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
+		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, index)) {
+			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
+			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
 		}
 
         g_free (printDate);
@@ -408,12 +419,9 @@ void countdown_home_widget_edit_event (GtkButton *button, CountdownHomeWidget *s
 		
 		countdown_home_widget_write_settings (self);
 		countdown_home_widget_update_content (self);
-    }
-	else if (response == GTK_RESPONSE_NO)
-	{
-		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->entries), &iter, NULL, index))
-		{
-			gtk_list_store_remove (self->entries, &iter);
+    } else if (response == GTK_RESPONSE_NO) {
+		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, index)) {
+			gtk_list_store_remove (self->priv->entries, &iter);
 		}
 		countdown_home_widget_write_settings (self);
 		countdown_home_widget_update_content (self);
@@ -449,18 +457,17 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (picker), HILDON_TOUCH_SELECTOR (selector));
 	
 	int i;
-	for (i=0; i<=60; i++)
-	{
+	for (i=0; i<=60; i++) {
 		gchar *text = g_strdup_printf ("%d minutes(s)", i);
 		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), text);
 		g_free (text);
 	}
-	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, self->refresh);
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, self->priv->refresh);
 	
 	refreshButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
 	g_signal_connect (G_OBJECT (refreshButton), "clicked", G_CALLBACK (countdown_home_widget_select_refresh), picker);
 	
-	gchar *text = g_strdup_printf ("%d minute(s)", self->refresh);
+	gchar *text = g_strdup_printf ("%d minute(s)", self->priv->refresh);
 	gtk_button_set_label (GTK_BUTTON (refreshButton), text);
 	
 	refreshCaption = hildon_caption_new (group, "Update every", refreshButton, NULL, HILDON_CAPTION_MANDATORY);
@@ -471,16 +478,15 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
     gtk_widget_show_all (dialog);
 
     int response=gtk_dialog_run (GTK_DIALOG (dialog));
-    if (response == GTK_RESPONSE_ACCEPT)
-    {
+    if (response == GTK_RESPONSE_ACCEPT) {
 		gint refresh = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
-		self->refresh = refresh;
+		self->priv->refresh = refresh;
 		
-		if (self->eventID != 0)
-		{
-			g_source_remove (self->eventID);
-			if (self->refresh > 0)
-				self->eventID = g_timeout_add (self->refresh*1000*60, (GSourceFunc)countdown_home_widget_update_content, self);
+		if (self->priv->eventID != 0) {
+			g_source_remove (self->priv->eventID);
+			if (self->priv->refresh > 0) {
+				self->priv->eventID = g_timeout_add (self->priv->refresh*1000*60, (GSourceFunc)countdown_home_widget_update_content, self);
+			}
 		}
 		
 		countdown_home_widget_write_settings (self);
@@ -497,22 +503,20 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
     GKeyFile *keyFile;
     GtkTreeIter iter;
 
-	self->entries = gtk_list_store_new (9, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
+	self->priv->entries = gtk_list_store_new (9, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
 
     keyFile = g_key_file_new();
     filename = g_strconcat (HOME_DIR, "/.countdown_home.ini", NULL);
     fileExists = g_key_file_load_from_file (keyFile, filename, G_KEY_FILE_KEEP_COMMENTS, NULL);
 
-    if (fileExists)
-    {
+    if (fileExists) {
         int i=0;
         gchar *entry;
         gboolean found;
         GError *error=NULL;
         entry = g_strdup_printf ("%d", i);
         found = g_key_file_has_group (keyFile, entry);
-        while (found)
-        {
+        while (found) {
             gchar *title, *date, *time, *readableTime;
             guint seconds, minutes, hours;
             gboolean *showWhich;
@@ -520,29 +524,25 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 
             sprintf (entry, "%d", i);
 			title=g_key_file_get_string(keyFile,entry,"title",&error);
-			if (error)
-			{
+			if (error) {
 				title="TITLE MISSING!";
-			g_error_free(error);
-			error=NULL;
+				g_error_free(error);
+				error=NULL;
 			}
 			date=g_key_file_get_string(keyFile,entry,"date",&error);
-			if (error)
-			{
+			if (error) {
 				date="INCORRECT DATE!";
-			g_error_free(error);
-			error=NULL;
+				g_error_free(error);
+				error=NULL;
 			}
 			time=g_key_file_get_string(keyFile,entry,"time",&error);
-			if (error)
-			{
+			if (error) {
 				time="0";
 				g_error_free(error);
 				error=NULL;
 			}
 			showWhich=g_key_file_get_boolean_list(keyFile,entry,"show",&length,&error);
-			if (error)
-			{
+			if (error) {
 				gboolean show[5]={TRUE,TRUE,TRUE,TRUE,TRUE};
 				showWhich=show;
 				g_error_free(error);
@@ -554,8 +554,8 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 			minutes=seconds/(60)-(hours*60);
 			readableTime=g_strdup_printf("%02d:%02d",hours,minutes);
 						
-			gtk_list_store_append(self->entries, &iter);
-			gtk_list_store_set(self->entries, &iter,0,title,1,date,2,time,3,readableTime,4,showWhich[0],5,showWhich[1],6,showWhich[2],7,showWhich[3],8,showWhich[4],-1);
+			gtk_list_store_append(self->priv->entries, &iter);
+			gtk_list_store_set(self->priv->entries, &iter,0,title,1,date,2,time,3,readableTime,4,showWhich[0],5,showWhich[1],6,showWhich[2],7,showWhich[3],8,showWhich[4],-1);
 			snprintf(entry,5,"%d",++i);
 			found=g_key_file_has_group(keyFile,entry);
 			g_free(readableTime);
@@ -564,77 +564,79 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 			g_free(time);
 			g_free(showWhich);
         }
-        self->refresh = g_key_file_get_integer (keyFile, "config", "refresh", &error);
-        if (error)
-        {
-            self->refresh = 1;
+        self->priv->refresh = g_key_file_get_integer (keyFile, "config", "refresh", &error);
+        if (error) {
+            self->priv->refresh = 1;
             g_error_free (error);
             error = NULL;
         }
-    }
-    else
-    {
-        self->refresh = 1;
+    } else {
+        self->priv->refresh = 1;
     }
 
     g_key_file_free (keyFile);
     g_free (filename);
 }
 
-void countdown_home_widget_scroll_up (GtkButton *button, CountdownHomeWidget *self)
+void countdown_home_widget_scroll_up (GtkWidget *button, GdkEventButton *event, CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_scroll_up");
-	self->offset--;
-	update_content (self);
+	self->priv->offset--;
+	countdown_home_widget_update_content (self);
 }
 
-void countdown_home_widget_scroll_down (GtkButton *button, CountdownHomeWidget *self)
+void countdown_home_widget_scroll_down (GtkWidget *button, GdkEventButton *event, CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_scroll_down");
-	self->offset++;
-	update_content (self);
+	self->priv->offset++;
+	countdown_home_widget_update_content (self);
 }
 
 void countdown_home_widget_content_create (CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_content_create");
-    self->contents = gtk_vbox_new (0, FALSE);
-	GtkVBox *scrollArea = GTK_VBOX (gtk_vbox_new (0, TRUE));
+	GtkWidget *align = gtk_alignment_new (1, 1, 0, 0);
+    self->priv->contents = gtk_vbox_new (TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (self->priv->contents), 0);
 
-    GtkWidget *addNewCountdown;
-    addNewCountdown = hildon_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_AUTO_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-    hildon_button_set_text (HILDON_BUTTON (addNewCountdown), "Create new", NULL);
+    GtkWidget *addNewCountdown = gtk_image_new_from_icon_name ("general_add", HILDON_ICON_SIZE_FINGER);
+	GtkWidget *addEvent = gtk_event_box_new ();
+	gtk_event_box_set_visible_window (GTK_EVENT_BOX (addEvent), FALSE);
+	gtk_container_add (GTK_CONTAINER (addEvent), addNewCountdown);
+	//gtk_button_set_image (GTK_BUTTON (addNewCountdown), addImage);
 
-    GtkHBox *buttons = GTK_HBOX (gtk_hbox_new (0, TRUE));
-	GtkHBox *hbox = GTK_HBOX (gtk_hbox_new (0, TRUE));
-	gtk_box_pack_start (GTK_BOX (hbox), self->contents, TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (scrollArea), FALSE, FALSE, 0);
+    self->priv->buttons = GTK_HBOX (gtk_hbox_new (TRUE, 0));
+	gtk_container_set_border_width (GTK_CONTAINER (self->priv->buttons), 0);
 	
-	self->upButton = gtk_button_new ();
-	self->downButton = gtk_button_new ();
-	g_signal_connect (self->upButton, "clicked", G_CALLBACK (countdown_home_widget_scroll_up), self);
-	g_signal_connect (self->downButton, "clicked", G_CALLBACK (countdown_home_widget_scroll_down), self);
+	self->priv->upButton = gtk_image_new_from_icon_name ("rss_reader_move_up", HILDON_ICON_SIZE_FINGER);
+	GtkWidget *upEvent = gtk_event_box_new ();
+	gtk_event_box_set_visible_window (GTK_EVENT_BOX (upEvent), FALSE);
+	gtk_container_add (GTK_CONTAINER (upEvent), self->priv->upButton);
+	self->priv->downButton = gtk_image_new_from_icon_name ("rss_reader_move_down", HILDON_ICON_SIZE_FINGER);
+	GtkWidget *downEvent = gtk_event_box_new ();
+	gtk_event_box_set_visible_window (GTK_EVENT_BOX (downEvent), FALSE);
+	gtk_container_add (GTK_CONTAINER (downEvent), self->priv->downButton);
+	g_signal_connect (upEvent, "button-release-event", G_CALLBACK (countdown_home_widget_scroll_up), self);
+	g_signal_connect (downEvent, "button-release-event", G_CALLBACK (countdown_home_widget_scroll_down), self);
 	
-	gtk_button_set_image (GTK_BUTTON (self->upButton), gtk_image_new_from_stock (GTK_STOCK_GO_UP, HILDON_ICON_SIZE_FINGER));
-	gtk_button_set_image (GTK_BUTTON (self->downButton), gtk_image_new_from_stock (GTK_STOCK_GO_DOWN, HILDON_ICON_SIZE_FINGER));
-	gtk_box_pack_start (GTK_BOX (scrollArea), self->upButton, TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (scrollArea), self->downButton, TRUE, TRUE, 0);
 	
-    gtk_container_add (GTK_CONTAINER (buttons), GTK_WIDGET (addNewCountdown));
+	gtk_container_add (GTK_CONTAINER (self->priv->buttons), GTK_WIDGET (addEvent));
+	gtk_container_add (GTK_CONTAINER (self->priv->buttons), GTK_WIDGET (upEvent));
+	gtk_container_add (GTK_CONTAINER (self->priv->buttons), GTK_WIDGET (downEvent));
     
-    g_signal_connect (addNewCountdown, "clicked", G_CALLBACK (countdown_home_widget_add_event), self);
+    g_signal_connect (addEvent, "button-release-event", G_CALLBACK (countdown_home_widget_add_event), self);
     
-    gtk_box_pack_start (GTK_BOX (self->homeWidget), GTK_WIDGET (hbox), FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (self->homeWidget), GTK_WIDGET (buttons), FALSE, FALSE, 0);
-    gtk_widget_show_all (self->homeWidget);
-	gtk_widget_hide (self->upButton);
-	gtk_widget_hide (self->downButton);
+    gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->contents), FALSE, FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (self->priv->homeWidget), align);
+    gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->buttons), FALSE, FALSE, 0);
+    gtk_widget_show_all (self->priv->homeWidget);
+	//gtk_widget_hide (self->priv->upButton);
+	//gtk_widget_hide (self->priv->downButton);
 }
 
 gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_update_content");
-	GtkWidget *vbox;
 	GDate *startDate=NULL, *endDate=NULL;
 	gint startSec=0, endSec=0;
 	time_t now;
@@ -654,17 +656,17 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 	
 	endDate = g_date_new ();
 
-	vbox = gtk_vbox_new (FALSE, 0);
-	
-	totalRows=gtk_tree_model_iter_n_children (GTK_TREE_MODEL (self->entries), NULL);
-	if (totalRows <= 3)
-	{
-		self->offset = 0;
+	totalRows=gtk_tree_model_iter_n_children (GTK_TREE_MODEL (self->priv->entries), NULL);
+	if (totalRows <= 3 || self->priv->offset < 0) {
+		self->priv->offset = 0;
+	} else if (totalRows > 3 && self->priv->offset > totalRows - 3) {
+		self->priv->offset = totalRows -3;
 	}
 	
-	exists = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->entries), &iter, NULL, self->offset);
-	while (exists)
-	{
+	gtk_container_foreach (GTK_CONTAINER (self->priv->contents), (GtkCallback) gtk_widget_destroy, NULL);
+	
+	exists = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, self->priv->offset);
+	while (exists) {
 		GtkWidget *countdownButton;
 		gchar *title="", *date="", *time="";
 		gint years=0, weeks=0, days=0;
@@ -679,50 +681,37 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 		gchar *tail="";
 		gboolean firstShown;
 		
-		gtk_tree_model_get (GTK_TREE_MODEL (self->entries), &iter, 0, &title, 1, &date, 2, &time, 4, &showYears, 5, &showWeeks, 6, &showDays, 7, &showHours, 8, &showMinutes, -1);
+		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->entries), &iter, 0, &title, 1, &date, 2, &time, 4, &showYears, 5, &showWeeks, 6, &showDays, 7, &showHours, 8, &showMinutes, -1);
 
 		seconds = g_ascii_strtoll (time, NULL,  10);
 		
 		g_date_set_parse (endDate, date);
-		if (!g_date_valid (endDate))
-		{
+		if (!g_date_valid (endDate)) {
 			title = g_strconcat (content[index++], "(INCORRECT DATE!)", NULL);
 			totDays = 0;
-		}
-		else
-		{
+		} else {
 			totDays = g_date_days_between (startDate, endDate);
 		}
 		
 		endSec = seconds;
 		seconds = endSec-startSec;
 		
-		if (totDays > 0)
-		{
+		if (totDays > 0) {
 			tail = g_strdup_printf ("left");
-			if (seconds < 0)
-			{
+			if (seconds < 0) {
 				totDays--;
 				seconds = (60*60*24)+seconds;
 			}
-		}
-		else if (totDays < 0)
-		{
+		} else if (totDays < 0) {
 			tail = g_strdup_printf ("ago");
-			if (seconds > 0)
-			{
+			if (seconds > 0) {
 				totDays++;
 				seconds = (60*60*24)-seconds;
 			}
-		}
-		else
-		{
-			if (seconds < 0)
-			{
+		} else {
+			if (seconds < 0) {
 				tail = g_strdup_printf ("ago");
-			}
-			else
-			{
+			} else {
 				tail = g_strdup_printf ("left");
 			}
 		}
@@ -732,52 +721,43 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 		totDays=ABS(totDays);
 		seconds=ABS(seconds);
 		
-		if (showYears)
-		{
+		if (showYears) {
 			years=totDays/365;
-			if ((firstShown)||(years!=0)||((!showWeeks)&&(!showDays)&&(!showHours)&&(!showMinutes)))
-			{
+			if ((firstShown)||(years!=0)||((!showWeeks)&&(!showDays)&&(!showHours)&&(!showMinutes))) {
 				firstShown = TRUE;
 				tempContent = g_strdup_printf ("%d", ABS (years));
 				content[index++] = g_strconcat (tempContent, " years ", NULL);
 				g_free (tempContent);
 			}
 		}
-		if (showWeeks)
-		{
+		if (showWeeks) {
 			weeks = (totDays-(years*365))/7;
-			if ((firstShown)||(weeks!=0)||((!showDays)&&(!showHours)&&(!showMinutes)))
-			{
+			if ((firstShown)||(weeks!=0)||((!showDays)&&(!showHours)&&(!showMinutes))) {
 				firstShown = TRUE;
 				tempContent = g_strdup_printf ("%d", ABS (weeks));
 				content[index++] = g_strconcat (tempContent, " weeks ", NULL);
 				g_free (tempContent);
 			}
 		}
-		if (showDays)
-		{
+		if (showDays) {
 			days = totDays-(weeks*7)-(years*365);
-			if ((firstShown)||(days!=0)||((!showHours)&&(!showMinutes)))
-			{
+			if ((firstShown)||(days!=0)||((!showHours)&&(!showMinutes))) {
 				firstShown = TRUE;
 				tempContent = g_strdup_printf ("%d", ABS (days));
 				content[index++] = g_strconcat (tempContent, " days ", NULL);
 				g_free (tempContent);
 			}
 		}
-		if (showHours)
-		{
+		if (showHours) {
 			hours = ((totDays-(days+(weeks*7)+(years*365)))*(24))+seconds/(60*60);
-			if ((firstShown)||(hours!=0)||(!showMinutes))
-			{
+			if ((firstShown)||(hours!=0)||(!showMinutes)) {
 				firstShown = TRUE;
 				tempContent = g_strdup_printf ("%d", ABS (hours));
 				content[index++] = g_strconcat (tempContent, " hours ", NULL);
 				g_free (tempContent);
 			}
 		}
-		if (showMinutes)
-		{
+		if (showMinutes) {
 			minutes=((totDays-(days+(weeks*7)+(years*365)))*(24*60))+((seconds/60)-(hours*60));
 			firstShown = TRUE;
 			tempContent = g_strdup_printf ("%d", ABS (minutes));
@@ -786,22 +766,25 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 		}
 		content[index] = g_strconcat (tail, NULL);
 		
-		countdownButton = hildon_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_AUTO_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
 		contentLabelText = g_strjoinv (NULL, content);
-		hildon_button_set_text (HILDON_BUTTON (countdownButton), title, contentLabelText);
-		hildon_button_set_title_alignment (HILDON_BUTTON (countdownButton), 0.0, 0.5);
-		hildon_button_set_value_alignment (HILDON_BUTTON (countdownButton), 0.0, 0.5);
-		hildon_button_add_size_groups (HILDON_BUTTON (countdownButton), titleGroup, valueGroup, NULL);
+		GtkWidget *event = gtk_event_box_new ();
+		gtk_event_box_set_visible_window (GTK_EVENT_BOX (event), FALSE);
+		gtk_container_set_border_width (GTK_CONTAINER (event), 5);
+		GtkWidget *vbox = gtk_vbox_new (TRUE, 0);
+		GtkWidget *titleLabel = gtk_label_new (title);
+		GtkWidget *contentLabel = gtk_label_new (contentLabelText);
+		gtk_container_add (GTK_CONTAINER (event), vbox);
+		gtk_container_add (GTK_CONTAINER (vbox), titleLabel);
+		gtk_container_add (GTK_CONTAINER (vbox), contentLabel);
+		gtk_container_add (GTK_CONTAINER (self->priv->contents), event);
 		
-		g_signal_connect (countdownButton, "clicked", G_CALLBACK (countdown_home_widget_edit_event), self);
+		g_signal_connect (event, "button-release-event", G_CALLBACK (countdown_home_widget_edit_event), self);
+		
+		gchar *name=g_strdup_printf("%d",self->priv->offset + count++);
+		
+		gtk_widget_set_name (event, name);
 		
-		gtk_box_pack_start (GTK_BOX (vbox), countdownButton, FALSE, FALSE, 0);
 		g_free (contentLabelText);
-		
-		gchar *name=g_strdup_printf("%d",self->offset + count++);
-		
-		gtk_widget_set_name (countdownButton, name);
-		
 		g_free (title);
 		g_free (date);
 		g_free (time);
@@ -809,39 +792,32 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 		g_free (tail);
 		g_strfreev (content);
 		
-		exists = gtk_tree_model_iter_next (GTK_TREE_MODEL (self->entries), &iter);
-		if (exists)
-		{
-			if (count >= 3)
-			{
+		exists = gtk_tree_model_iter_next (GTK_TREE_MODEL (self->priv->entries), &iter);
+		if (exists) {
+			if (count >= 3) {
 				exists = FALSE;
 			}
 		}
 	}
 
 	if (totalRows > 3) {
-		gtk_widget_show (self->downButton);
-		gtk_widget_show (self->upButton);
-		
-		if (self->offset == 0) {
-			gtk_widget_set_sensitive (self->upButton, FALSE);
+		if (self->priv->offset == 0) {
+			gtk_widget_set_sensitive (self->priv->upButton, FALSE);
 		} else {
-			gtk_widget_set_sensitive (self->upButton, TRUE);
+			gtk_widget_set_sensitive (self->priv->upButton, TRUE);
 		}
 		
-		if (self->offset + 3 >= totalRows) {
-			gtk_widget_set_sensitive (self->downButton, FALSE);
+		if (self->priv->offset + 3 >= totalRows) {
+			gtk_widget_set_sensitive (self->priv->downButton, FALSE);
 		} else {
-			gtk_widget_set_sensitive (self->downButton, TRUE);
+			gtk_widget_set_sensitive (self->priv->downButton, TRUE);
 		}
 	} else {
-		gtk_widget_hide (self->downButton);
-		gtk_widget_hide (self->upButton);
+		gtk_widget_set_sensitive (self->priv->upButton, FALSE);
+		gtk_widget_set_sensitive (self->priv->downButton, FALSE);
 	}
 
-	gtk_container_foreach (GTK_CONTAINER (self->contents), (GtkCallback) gtk_widget_destroy, NULL);
-	gtk_container_add (GTK_CONTAINER (self->contents), vbox);
-	gtk_widget_show_all (self->contents);
+	gtk_widget_show_all (self->priv->contents);
 	
 	g_date_free (startDate);
 	g_date_free (endDate);
@@ -855,26 +831,45 @@ static void countdown_home_widget_check_desktop (GObject *gobject, GParamSpec *p
 	gchar *name = pspec->name;
 	gboolean status;
 	g_object_get (gobject, name, &status, NULL);
-	if (status)
-	{
+	if (status) {
 		countdown_home_widget_update_content (self);
-		if (self->eventID == 0)
-		{
-			if (self->refresh > 0)
-				self->eventID = g_timeout_add (self->refresh*1000*60, (GSourceFunc)countdown_home_widget_update_content, self);
+		if (self->priv->eventID == 0) {
+			if (self->priv->refresh > 0) {
+				self->priv->eventID = g_timeout_add (self->priv->refresh*1000*60, (GSourceFunc)countdown_home_widget_update_content, self);
+			}
 		}
+	} else if (self->priv->eventID != 0) {
+		g_source_remove (self->priv->eventID);
+		self->priv->eventID = 0;
 	}
-	else if (self->eventID != 0)
-	{
-		g_source_remove (self->eventID);
-		self->eventID = 0;
+}
+
+static void countdown_home_widget_dispose (GObject *object)
+{
+	//g_warning ("countdown_home_widget_dispose");
+	CountdownHomeWidget *self = COUNTDOWN_HOME_WIDGET (object);
+
+	G_OBJECT_CLASS (countdown_home_widget_parent_class)->dispose (object);
+}
+
+static void countdown_home_widget_finalize (GObject *object)
+{
+	//g_warning ("countdown_home_widget_finalize");
+	CountdownHomeWidget *self = COUNTDOWN_HOME_WIDGET (object);
+
+	if (self->priv->eventID) {
+		g_source_remove (self->priv->eventID);
 	}
+
+	G_OBJECT_CLASS (countdown_home_widget_parent_class)->finalize (object);
 }
 
 static void countdown_home_widget_realize (GtkWidget *widget)
 {
 	//g_warning ("countdown_home_widget_realize");
-	GdkScreen *screen = gtk_widget_get_screen (widget);
+	GdkScreen *screen;
+
+	screen = gtk_widget_get_screen (widget);
 	gtk_widget_set_colormap (widget, gdk_screen_get_rgba_colormap (screen));
 
 	gtk_widget_set_app_paintable (widget, TRUE);
@@ -883,52 +878,65 @@ static void countdown_home_widget_realize (GtkWidget *widget)
 }
 
 static gboolean countdown_home_widget_expose_event (GtkWidget *widget, GdkEventExpose *event)
-{    
+{
 	//g_warning ("countdown_home_widget_expose_event");
-	
 	cairo_t *cr;
-	cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
 
-	cairo_save (cr);
-	cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
-	cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 0.5);
-	cairo_rectangle (cr, event->area.x, event->area.y, event->area.width, event->area.height);
-	cairo_fill (cr);
-	cairo_restore (cr);
+	/* Create cairo context */
+    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
 
-	cairo_destroy (cr);
+    /* Draw alpha background */
+    cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+    cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.0);
+    cairo_paint (cr);
 
-  return FALSE;
-}
+    /* Free context */
+    cairo_destroy (cr);
+	
+	cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
+	cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
+	
+	gint width, height, x, y, radius=10;
+	width = widget->allocation.width;
+	height = widget->allocation.height;
+	x = widget->allocation.x;
+	y = widget->allocation.y;
 
-static void countdown_home_widget_dispose (GObject *object)
-{
-  CountdownHomeWidget *self = COUNTDOWN_HOME_WIDGET (object);
- 
-  G_OBJECT_CLASS (countdown_home_widget_parent_class)->dispose (object);
-}
+	cairo_move_to(cr, x + radius, y);
+	cairo_line_to(cr, x + width - radius, y);
+	cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
+				y + radius);
+	cairo_line_to(cr, x + width, y + height - radius);
+	cairo_curve_to(cr, x + width, y + height - radius, x + width,
+				y + height, x + width - radius, y + height);
+	cairo_line_to(cr, x + radius, y + height);
+	cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
+				y + height - radius);
+	cairo_line_to(cr, x, y + radius);
+	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
 
-static void countdown_home_widget_finalize (GObject *object)
-{
-  CountdownHomeWidget *self = COUNTDOWN_HOME_WIDGET (object);
- 
-  if (self->eventID) {
-    g_source_remove (self->eventID);
-  }
-  
-  G_OBJECT_CLASS (countdown_home_widget_parent_class)->finalize (object);
+	/* Draw alpha background */
+	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+
+	cairo_fill(cr);
+	cairo_destroy(cr);
+
+	return GTK_WIDGET_CLASS (countdown_home_widget_parent_class)->expose_event (widget, event);
 }
 
 static void countdown_home_widget_class_init (CountdownHomeWidgetClass *klass)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+	//g_warning ("countdown_home_widget_class_init");
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-  object_class->dispose = countdown_home_widget_dispose;
-  object_class->finalize = countdown_home_widget_finalize;
- 
-  //widget_class->realize = countdown_home_widget_realize;
-  //widget_class->expose_event = countdown_home_widget_expose_event;
+	object_class->dispose = countdown_home_widget_dispose;
+	object_class->finalize = countdown_home_widget_finalize;
+	
+	widget_class->realize = countdown_home_widget_realize;
+	widget_class->expose_event = countdown_home_widget_expose_event;
+
+	g_type_class_add_private (klass, sizeof (CountdownHomeWidgetPrivate));
 }
 
 static void countdown_home_widget_class_finalize (CountdownHomeWidgetClass *klass G_GNUC_UNUSED)
@@ -938,27 +946,35 @@ static void countdown_home_widget_class_finalize (CountdownHomeWidgetClass *klas
 static void countdown_home_widget_init (CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_init");
-	self->offset = 0;
-	self->eventID = 0;
-	hd_home_plugin_item_set_settings (&self->hitem, TRUE);
-	g_signal_connect (&self->hitem, "show-settings", G_CALLBACK (countdown_home_widget_global_options), self);
+	self->priv = COUNTDOWN_HOME_WIDGET_GET_PRIVATE (self);
+	self->priv->offset = 0;
+	self->priv->eventID = 0;
 	
-	self->homeWidget = gtk_vbox_new (0, FALSE);
-	gtk_container_add (GTK_CONTAINER (self), self->homeWidget);
-	gtk_widget_show_all (self->homeWidget);
+	gtk_window_set_default_size (GTK_WINDOW (self), 352, 252);
 	
-	gtk_window_set_opacity (GTK_WINDOW (self), 0.5);
+	hd_home_plugin_item_set_settings (&self->parent, TRUE);
+	g_signal_connect (&self->parent, "show-settings", G_CALLBACK (countdown_home_widget_global_options), self);
+	
+	self->priv->homeWidget = gtk_vbox_new (FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (self->priv->homeWidget), 0);
+	gtk_container_add (GTK_CONTAINER (self), self->priv->homeWidget);
+	gtk_widget_show (self->priv->homeWidget);
 
+	GdkGeometry hints;
+	hints.min_width = 352;
+	hints.min_height = 252;
+	hints.max_width = 352;
+	hints.max_height = 252;
+	gtk_window_set_geometry_hints (GTK_WINDOW (self), self->priv->homeWidget, &hints, GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
+	
 	countdown_home_widget_make_view (self);
-
+	
 	countdown_home_widget_content_create (self);
-
-	g_signal_connect (&self->hitem, "notify::is-on-current-desktop", G_CALLBACK (countdown_home_widget_check_desktop), self);
+	
+	g_signal_connect (self, "notify::is-on-current-desktop", G_CALLBACK (countdown_home_widget_check_desktop), self);
 }
 
 CountdownHomeWidget* countdown_home_widget_new (void)
 {
   return g_object_new (COUNTDOWN_TYPE_HOME_WIDGET, NULL);
 }
-
-
